@@ -1002,7 +1002,10 @@ class WorkflowTools(object):
 
         action = evaluate.static(workflow)
 
-        return action
+        if action['parameters']['Action']:
+            return action
+
+        return {}
 
 
     @cherrypy.expose
@@ -1030,9 +1033,9 @@ class WorkflowTools(object):
 
                 if params:
                     if dry:
-                        print(submission)
+                        print(workflow)
                     else:
-                        manageactions.submit2(user, [submission])
+                        manageactions.submit2(user, [params])
 
             self.update_statuses()
 
